@@ -16,7 +16,10 @@ limitations under the License.
 
 """
 
-from falcon.status_codes import *
+from falcon.status_codes import HTTP_400
+from falcon.status_codes import HTTP_404
+from falcon.status_codes import HTTP_405
+from falcon.status_codes import HTTP_500
 
 
 def path_not_found(req, resp, **kwargs):
@@ -35,7 +38,7 @@ def internal_server_error(req, resp, **kwargs):
 
 
 def create_method_not_allowed(allowed_methods):
-    """Creates a responder for "405 Method Not Allowed".ipyth
+    """Creates a responder for "405 Method Not Allowed"
 
     Args:
         allowed_methods: A list of HTTP methods (uppercase) that should be
